==> rc-ui-lib-0.1.29.tgz: package/es/action-bar/ActionBarButton.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import { createNamespace } from '../utils';
import { Button } from '../button';
import ActionBarContext from './ActionBarContext';

var _createNamespace = createNamespace('action-bar-button'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var ActionBarButton = function ActionBarButton(props) {
  var type = props.type,
      icon = props.icon,
      text = props.text,
      color = props.color,
      loading = props.loading,
      disabled = props.disabled,
      index = props.index;

  var _useContext = useContext(ActionBarContext),
      parent = _useContext.parent;

  var isFirst = useMemo(function () {
    if (parent) {
      var prev = parent.children[index - 1];
      return !(prev && 'isButton' in prev.type);
    }

    return false;
  }, [index, parent]);
  var isLast = useMemo(function () {
    if (parent) {
      var next = parent.children[index + 1];
      return !(next && 'isButton' in next.type);
    }

    return false;
  }, [index, parent]);
  return /*#__PURE__*/React.createElement(Button, {
    className: classnames(props.className, bem([type, {
      last: isLast,
      first: isFirst
    }])),
    style: props.style,
    size: "large",
    type: type,
    icon: icon,
    color: color,
    loading: loading,
    disabled: disabled,
    onClick: props.onClick
  }, props.children ? props.children : text);
};

var ActionBarButtonNameSpace = Object.assign(ActionBarButton, {
  isButton: true
});
export default ActionBarButtonNameSpace;

==> rc-ui-lib-0.1.35.tgz: package/es/action-bar/ActionBarButton.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import { Button } from '../button';
import ActionBarContext from './ActionBarContext';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var ActionBarButton = function ActionBarButton(props) {
  var type = props.type,
      icon = props.icon,
      text = props.text,
      color = props.color,
      loading = props.loading,
      disabled = props.disabled,
      index = props.index;

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('action-bar-button', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useContext2 = useContext(ActionBarContext),
      parent = _useContext2.parent;

  var isFirst = useMemo(function () {
    if (parent) {
      var prev = parent.children[index - 1];
      return !(prev && 'isButton' in prev.type);
    }

    return false;
  }, [index, parent]);
  var isLast = useMemo(function () {
    if (parent) {
      var next = parent.children[index + 1];
      return !(next && 'isButton' in next.type);
    }

    return false;
  }, [index, parent]);
  return /*#__PURE__*/React.createElement(Button, {
    className: classnames(props.className, bem([type, {
      last: isLast,
      first: isFirst
    }])),
    style: props.style,
    size: "large",
    type: type,
    icon: icon,
    color: color,
    loading: loading,
    disabled: disabled,
    onClick: props.onClick
  }, props.children ? props.children : text);
};

var ActionBarButtonNameSpace = Object.assign(ActionBarButton, {
  isButton: true
});
export default ActionBarButtonNameSpace;
